@@ -51,6 +51,10 @@ pub struct MultiFuse<T> {
     inner: Fuse<(MultiBomb<T>, T)>
 }
 
+// SAFETY: lighting a `MultiFuse` requires a &mut self, which
+// ensures that there is only one instance modifying the internal state.
+unsafe impl<T> Sync for MultiFuse<T> { }
+
 impl<T> MultiBomb<T> {
     /// Creates a new single but reusable producer [`MultiFuse<T>`], and a mutli-consumer `MultiBomb<T>`.
     /// 
